Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1365)

Unified Diff: webrtc/modules/congestion_controller/congestion_controller_unittest.cc

Issue 2415543002: Set min BWE bitrate form 10kbps to 5kbps and centralize minimum bitrate. (Closed)
Patch Set: Response to comments Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webrtc/modules/congestion_controller/congestion_controller_unittest.cc
diff --git a/webrtc/modules/congestion_controller/congestion_controller_unittest.cc b/webrtc/modules/congestion_controller/congestion_controller_unittest.cc
index e840294d9f09a96da12b5631606ab717c2227e16..e5102e62484009efc68525052bf05af283ce8c64 100644
--- a/webrtc/modules/congestion_controller/congestion_controller_unittest.cc
+++ b/webrtc/modules/congestion_controller/congestion_controller_unittest.cc
@@ -11,6 +11,7 @@
#include "webrtc/call/mock/mock_rtc_event_log.h"
#include "webrtc/modules/bitrate_controller/include/bitrate_controller.h"
#include "webrtc/modules/congestion_controller/include/congestion_controller.h"
+#include "webrtc/modules/congestion_controller/include/defines.h"
#include "webrtc/modules/congestion_controller/include/mock/mock_congestion_controller.h"
#include "webrtc/modules/pacing/mock/mock_paced_sender.h"
#include "webrtc/modules/remote_bitrate_estimator/include/mock/mock_remote_bitrate_observer.h"
@@ -135,10 +136,11 @@ TEST_F(CongestionControllerTest, ResetBweAndBitrates) {
controller_->ResetBweAndBitrates(new_bitrate, -1, -1);
// If the bitrate is reset to -1, the new starting bitrate will be
- // the minimum default bitrate 10000bps.
- int min_default_bitrate = 10000;
- EXPECT_CALL(observer_, OnNetworkChanged(min_default_bitrate, _, _));
- EXPECT_CALL(*pacer_, SetEstimatedBitrate(min_default_bitrate));
+ // the minimum default bitrate kMinBitrateBps.
+ EXPECT_CALL(observer_,
+ OnNetworkChanged(congestion_controller::kMinBitrateBps, _, _));
+ EXPECT_CALL(*pacer_,
+ SetEstimatedBitrate(congestion_controller::kMinBitrateBps));
controller_->ResetBweAndBitrates(-1, -1, -1);
}

Powered by Google App Engine
This is Rietveld 408576698